
# DO NOT EDIT #

The files in this directory were auto-generated using [openapi-python-client](https://github.com/openapi-generators/openapi-python-client).
To update them, please run `myst maint generate-api-client`.
